
// TimeResponder.java
// Andrew Davison, March 2009, ad@fivedots.coe.psu.ac.th

/*  An example of Scratch's remote sensor connections.

    A Scratch/Java application where Java is an information
    supplier used by a Scratch application (MyClock.sb).

    A clock in MyClock.sb in is periodically kept up-to-date by sending a 
    TimeRequest message to this Java code. It updates three virtual
    sensors (called Hour, Minute, and Second), and then sends a 
    Refresh message to Scratch.

    Before this Java program is started, the Scratch program must 
    already be loaded, and remote sensor connections switched on.
*/


import java.text.*;
import java.util.*;



public class TimeResponder
{

  public static void main(String argv[])
  {
    SimpleDateFormat fmt = new SimpleDateFormat("h:mm:ss a");
    ScratchIO sio = new ScratchIO();

    while(true) {
      System.out.println("Waiting...");
      ScratchMessage msg = sio.readMsg();    // wait for time request
      System.out.println("Received: " + msg);
      sendRefresh(sio, fmt);
    }
  }  // end of main()



  private static void sendRefresh(ScratchIO sio, SimpleDateFormat fmt)
  // update the three virtual sensors, and send a Refresh message
  {
    Calendar c = Calendar.getInstance();
    System.out.println("Sending time: " + fmt.format(c.getTime()));

    sio.updateMsg("Hour", "" + c.get(Calendar.HOUR));
    sio.updateMsg("Minute", "" + c.get(Calendar.MINUTE));
    sio.updateMsg("Second", "" + c.get(Calendar.SECOND));

    sio.broadcastMsg("Refresh");
  } // end of sendRefresh()


} // emd of TimeResponder class
