
// TrampolineWatcher.java
// Andrew Davison, March 2009, ad@fivedots.coe.psu.ac.th

/* A threaded TrampolineWatcher object watches for messages 
   coming from the JavaTrampline.sb Scratch application

   The messages are placed in the TrampolineClient's
   GUI text area by calling its showMsg() method.
*/

import javax.swing.*;
import java.io.*;
import java.net.*;
import java.util.*;


public class TrampolineWatcher extends Thread
{
  private TrampolineClient client;   // link to Java client
  private ScratchIO scratchIO;       // link to Scratch application
  private volatile boolean isFinished;


  public TrampolineWatcher(TrampolineClient c, ScratchIO sio)
  {  client = c; 
     scratchIO = sio;  
     isFinished = false;
  }  // end of TrampolineWatcher()


  public void finish()
  {  isFinished = true;  }



  public void run()
  // Read a scratch message, display it, repeat.
  { 
    ScratchMessage scratchMsg;
    try {
      while (!isFinished) {
        scratchMsg = scratchIO.readMsg();
        if (scratchMsg != null)
          client.showMsg(scratchMsg.toString() + "\n");
      }
    }
    catch(Exception e)    // socket closure will cause termination of while
    { // System.out.println( e );  
      JOptionPane.showMessageDialog( null, 
           "Link to Scratch Lost!", "Connection Closed", 
			JOptionPane.ERROR_MESSAGE);
      System.exit(0);
    }
  } // end of run()

}  // end of TrampolineWatcher class